@@ -12,24 +12,49 @@ from bip_utils.ss58 import (
 )
 # Bech32
 from bip_utils.bech32 import (
-    Bech32ChecksumError, Bech32FormatError,
+    Bech32ChecksumError,
     Bech32Decoder, Bech32Encoder,
     BchBech32Decoder, BchBech32Encoder,
     SegwitBech32Decoder, SegwitBech32Encoder
 )
 # WIF
-from bip_utils.wif import WifDecoder, WifEncoder
+from bip_utils.wif import WifPubKeyModes, WifDecoder, WifEncoder
 # Address computation
 from bip_utils.addr import (
     BchAddrConverter,
-    AlgoAddr, AtomAddr, AvaxPChainAddr, AvaxXChainAddr, EgldAddr, EosAddr,
-    EthAddr, FilSecp256k1Addr, OkexAddr, NanoAddr, NeoAddr, OneAddr,
-    P2PKHAddr, BchP2PKHAddr, P2SHAddr, BchP2SHAddr, P2WPKHAddr, SolAddr,
-    SubstrateEd25519Addr, SubstrateSr25519Addr, TrxAddr, XlmAddrTypes, XlmAddr, XmrIntegratedAddr,
-    XmrAddr, XrpAddr, XtzAddrPrefixes, XtzAddr, ZilAddr
+    AlgoAddrDecoder, AlgoAddrEncoder, AlgoAddr,
+    AtomAddrDecoder, AtomAddrEncoder, AtomAddr,
+    AvaxPChainAddrDecoder, AvaxPChainAddrEncoder, AvaxPChainAddr,
+    AvaxXChainAddrDecoder, AvaxXChainAddrEncoder, AvaxXChainAddr,
+    EgldAddrDecoder, EgldAddrEncoder, EgldAddr,
+    EosAddrDecoder, EosAddrEncoder, EosAddr,
+    EthAddrDecoder, EthAddrEncoder, EthAddr,
+    FilSecp256k1AddrDecoder, FilSecp256k1AddrEncoder, FilSecp256k1Addr,
+    NanoAddrDecoder, NanoAddrEncoder, NanoAddr,
+    NearAddrDecoder, NearAddrEncoder, NearAddr,
+    NeoAddrDecoder, NeoAddrEncoder, NeoAddr,
+    OkexAddrDecoder, OkexAddrEncoder, OkexAddr,
+    OneAddrDecoder, OneAddrEncoder, OneAddr,
+    BchP2PKHAddrDecoder, BchP2PKHAddrEncoder, BchP2PKHAddr,
+    P2PKHAddrDecoder, P2PKHAddrEncoder, P2PKHAddr,
+    BchP2SHAddrDecoder, BchP2SHAddrEncoder, BchP2SHAddr,
+    P2SHAddrDecoder, P2SHAddrEncoder, P2SHAddr,
+    P2WPKHAddrDecoder, P2WPKHAddrEncoder, P2WPKHAddr,
+    SolAddrDecoder, SolAddrEncoder, SolAddr,
+    SubstrateEd25519AddrDecoder, SubstrateEd25519AddrEncoder, SubstrateEd25519Addr,
+    SubstrateSr25519AddrDecoder, SubstrateSr25519AddrEncoder, SubstrateSr25519Addr,
+    TrxAddrDecoder, TrxAddrEncoder, TrxAddr,
+    XlmAddrTypes, XlmAddrDecoder, XlmAddrEncoder, XlmAddr,
+    XmrAddrDecoder, XmrAddrEncoder, XmrAddr,
+    XmrIntegratedAddrDecoder, XmrIntegratedAddrEncoder, XmrIntegratedAddr,
+    XrpAddrDecoder, XrpAddrEncoder, XrpAddr,
+    XtzAddrPrefixes, XtzAddrDecoder, XtzAddrEncoder, XtzAddr,
+    ZilAddrDecoder, ZilAddrEncoder, ZilAddr
 )
 # Generic coins configuration
 from bip_utils.coin_conf import CoinsConf
+# BIP38
+from bip_utils.bip.bip38 import Bip38PubKeyModes, Bip38EcKeysGenerator, Bip38Decrypter, Bip38Encrypter
 # BIP39
 from bip_utils.bip.bip39 import (
     Bip39ChecksumError,
@@ -54,9 +79,9 @@ from bip_utils.bip.bip44 import Bip44
 from bip_utils.bip.bip49 import Bip49
 from bip_utils.bip.bip84 import Bip84
 # BIP coins configuration
-from bip_utils.bip.conf.bip44 import Bip44Coins, Bip44Conf
-from bip_utils.bip.conf.bip49 import Bip49Coins, Bip49Conf
-from bip_utils.bip.conf.bip84 import Bip84Coins, Bip84Conf
+from bip_utils.bip.conf.bip44 import Bip44Coins, Bip44Conf, Bip44ConfGetter
+from bip_utils.bip.conf.bip49 import Bip49Coins, Bip49Conf, Bip49ConfGetter
+from bip_utils.bip.conf.bip84 import Bip84Coins, Bip84Conf, Bip84ConfGetter
 # Monero
 from bip_utils.monero import (
     MoneroKeyError, MoneroPublicKey, MoneroPrivateKey, MoneroSubaddress, Monero
@@ -93,5 +118,5 @@ from bip_utils.ecc import (
 )
 # Utils
 from bip_utils.utils.misc import (
-    AlgoUtils, BitUtils, ConvUtils, CryptoUtils, DataBytes
+    AlgoUtils, BitUtils, BytesUtils, CryptoUtils, DataBytes
 )
