@@ -51,6 +51,14 @@ class CoinsConf:
         },
     )
 
+    # Configuration for Akash Network
+    AkashNetwork: CoinConf = CoinConf(
+        coin_name=CoinNames("Akash Network", "AKT"),
+        params={
+            "addr_hrp": "akash",
+        },
+    )
+
     # Configuration for Algorand
     Algorand: CoinConf = CoinConf(
         coin_name=CoinNames("Algorand", "ALGO"),
@@ -140,7 +148,7 @@ class CoinsConf:
         coin_name=CoinNames("Bitcoin Cash", "BCH"),
         params={
             "p2pkh_std_hrp": "bitcoincash",
-            "p2pkh_std_net_ver": b"\x00",
+            "p2pkh_std_net_ver": _BTC_P2PKH_NET_VER_MN,
             "p2pkh_legacy_net_ver": _BTC_P2PKH_NET_VER_MN,
             "p2sh_std_hrp": "bitcoincash",
             "p2sh_std_net_ver": b"\x08",
@@ -217,6 +225,14 @@ class CoinsConf:
         params={},
     )
 
+    # Configuration for Certik
+    Certik: CoinConf = CoinConf(
+        coin_name=CoinNames("Certik", "CTK"),
+        params={
+            "addr_hrp": "certik",
+        },
+    )
+
     # Configuration for ChainX
     ChainX: CoinConf = CoinConf(
         coin_name=CoinNames("ChainX", "PCX"),
@@ -225,6 +241,14 @@ class CoinsConf:
         },
     )
 
+    # Configuration for Chihuahua
+    Chihuahua: CoinConf = CoinConf(
+        coin_name=CoinNames("Chihuahua", "HUAHUA"),
+        params={
+            "addr_hrp": "chihuahua",
+        },
+    )
+
     # Configuration for Cosmos
     Cosmos: CoinConf = CoinConf(
         coin_name=CoinNames("Cosmos", "ATOM"),
@@ -489,6 +513,12 @@ class CoinsConf:
         },
     )
 
+    # Configuration for Near Protocol
+    NearProtocol: CoinConf = CoinConf(
+        coin_name=CoinNames("Near Protocol", "NEAR"),
+        params={},
+    )
+
     # Configuration for Neo
     Neo: CoinConf = CoinConf(
         coin_name=CoinNames("NEO", "NEO"),
@@ -519,6 +549,14 @@ class CoinsConf:
         },
     )
 
+    # Configuration for Osmosis
+    Osmosis: CoinConf = CoinConf(
+        coin_name=CoinNames("Osmosis", "OSMO"),
+        params={
+            "addr_hrp": "osmo",
+        },
+    )
+
     # Configuration for Phala
     Phala: CoinConf = CoinConf(
         coin_name=CoinNames("Phala Network", "PHA"),
@@ -557,6 +595,14 @@ class CoinsConf:
         },
     )
 
+    # Configuration for Secret Network
+    SecretNetwork: CoinConf = CoinConf(
+        coin_name=CoinNames("Secret Network", "SCRT"),
+        params={
+            "addr_hrp": "secret",
+        },
+    )
+
     # Configuration for Solana
     Solana: CoinConf = CoinConf(
         coin_name=CoinNames("Solana", "SOL"),
@@ -619,6 +665,15 @@ class CoinsConf:
         params={},
     )
 
+    # Configuration for Verge
+    Verge: CoinConf = CoinConf(
+        coin_name=CoinNames("Verge", "XVG"),
+        params={
+            "p2pkh_net_ver": b"\x1e",
+            "wif_net_ver": b"\x9e",
+        },
+    )
+
     # Configuration for Zcash main net
     ZcashMainNet: CoinConf = CoinConf(
         coin_name=CoinNames("Zcash", "ZEC"),
