@@ -21,11 +21,20 @@
 """Module for WIF encoding/decoding."""
 
 # Imports
-from typing import Union
+from enum import auto, Enum, unique
+from typing import Tuple, Union
 from bip_utils.base58 import Base58Decoder, Base58Encoder
 from bip_utils.coin_conf import CoinsConf
 from bip_utils.ecc import IPrivateKey, Secp256k1PrivateKey
-from bip_utils.utils.misc import ConvUtils
+from bip_utils.utils.misc import BytesUtils
+
+
+@unique
+class WifPubKeyModes(Enum):
+    """Enumerative for WIF public key modes."""
+
+    COMPRESSED = auto()
+    UNCOMPRESSED = auto()
 
 
 class WifConst:
@@ -44,22 +53,25 @@ class WifEncoder:
     @staticmethod
     def Encode(priv_key: Union[bytes, IPrivateKey],
                net_ver: bytes = CoinsConf.BitcoinMainNet.Params("wif_net_ver"),
-               compr_pub_key: bool = True) -> str:
+               pub_key_mode: WifPubKeyModes = WifPubKeyModes.COMPRESSED) -> str:
         """
         Encode key bytes into a WIF string.
 
         Args:
-            priv_key (bytes or IPrivateKey): Private key bytes or object
-            net_ver (bytes, optional)      : Net version (Bitcoin main net by default)
-            compr_pub_key (bools, optional): True if private key corresponds to a compressed public key,
-                                             false otherwise
+            priv_key (bytes or IPrivateKey)        : Private key bytes or object
+            net_ver (bytes, optional)              : Net version (Bitcoin main net by default)
+            pub_key_mode (WifPubKeyModes, optional): Specify if the private key corresponds to a compressed public key
 
         Returns:
             str: WIF encoded string
 
         Raises:
+            TypeError: If pub_key_mode is not a WifPubKeyModes enum or
+                       the private key is not a valid Secp256k1PrivateKey
             ValueError: If the key is not valid
         """
+        if not isinstance(pub_key_mode, WifPubKeyModes):
+            raise TypeError("Public key mode is not an enumerative of WifPubKeyModes")
 
         # Convert to private key to check if bytes are valid
         if isinstance(priv_key, bytes):
@@ -70,7 +82,7 @@ class WifEncoder:
         priv_key = priv_key.Raw().ToBytes()
 
         # Add suffix if correspond to a compressed public key
-        if compr_pub_key:
+        if pub_key_mode == WifPubKeyModes.COMPRESSED:
             priv_key += WifConst.COMPR_PUB_KEY_SUFFIX
 
         # Add net address version
@@ -88,7 +100,7 @@ class WifDecoder:
 
     @staticmethod
     def Decode(wif_str: str,
-               net_ver: bytes = CoinsConf.BitcoinMainNet.Params("wif_net_ver")) -> bytes:
+               net_ver: bytes = CoinsConf.BitcoinMainNet.Params("wif_net_ver")) -> Tuple[bytes, WifPubKeyModes]:
         """
         Decode key bytes from a WIF string.
 
@@ -97,7 +109,7 @@ class WifDecoder:
             net_ver (bytes, optional): Net version (Bitcoin main net by default)
 
         Returns:
-            bytes: Key bytes
+            tuple: Key bytes (index 0), public key mode (index 1)
 
         Raises:
             Base58ChecksumError: If the base58 checksum is not valid
@@ -105,28 +117,31 @@ class WifDecoder:
         """
 
         # Decode string
-        key_bytes = Base58Decoder.CheckDecode(wif_str)
+        priv_key_bytes = Base58Decoder.CheckDecode(wif_str)
 
         # Check net version
-        if key_bytes[0] != ord(net_ver):
+        if priv_key_bytes[0] != ord(net_ver):
             raise ValueError(
-                f"Invalid net version (expected 0x{ord(net_ver):02X}, got 0x{key_bytes[0]:02X})"
+                f"Invalid net version (expected 0x{ord(net_ver):02X}, got 0x{priv_key_bytes[0]:02X})"
             )
 
         # Remove net version
-        key_bytes = key_bytes[1:]
+        priv_key_bytes = priv_key_bytes[1:]
 
         # Remove suffix if correspond to a compressed public key
-        if Secp256k1PrivateKey.IsValidBytes(key_bytes[:-1]):
+        if Secp256k1PrivateKey.IsValidBytes(priv_key_bytes[:-1]):
             # Check the compressed public key suffix
-            if key_bytes[-1] != ord(WifConst.COMPR_PUB_KEY_SUFFIX):
+            if priv_key_bytes[-1] != ord(WifConst.COMPR_PUB_KEY_SUFFIX):
                 raise ValueError(
                     f"Invalid compressed public key suffix (expected 0x{ord(WifConst.COMPR_PUB_KEY_SUFFIX):02X}, "
-                    f"got 0x{key_bytes[-1]:02X})"
+                    f"got 0x{priv_key_bytes[-1]:02X})"
                 )
             # Remove it
-            key_bytes = key_bytes[:-1]
-        elif not Secp256k1PrivateKey.IsValidBytes(key_bytes):
-            raise ValueError(f"Invalid decoded key ({ConvUtils.BytesToHexString(key_bytes)})")
+            priv_key_bytes = priv_key_bytes[:-1]
+            pub_key_mode = WifPubKeyModes.COMPRESSED
+        else:
+            if not Secp256k1PrivateKey.IsValidBytes(priv_key_bytes):
+                raise ValueError(f"Invalid decoded key ({BytesUtils.ToHexString(priv_key_bytes)})")
+            pub_key_mode = WifPubKeyModes.UNCOMPRESSED
 
-        return key_bytes
+        return priv_key_bytes, pub_key_mode
